{ config, pkgs, ... }:

{
  imports = [
    ../home-modules/matugen.nix
  ];

  home.username = "proto";
  home.homeDirectory = "/home/proto";
  home.stateVersion = "23.11";
  #programs.home-manager.enable = true;

  programs.matugen = {
    enable = true;
    #wallpaper = "${pkgs.sway}/share/backgrounds/sway/Sway_Wallpaper_Blue_1920x1080.png";
    wallpaper = ./background.jpg;
    templates = {
      "gtk" = {
        source = ./gtk.css;
        destination = "gtk.css";
      };
    };
  };

  xdg.configFile."gtk-3.0/gtk.css" = {
    source = "${config.programs.matugen.theme.files}/gtk.css";
  };
  xdg.configFile."gtk-4.0/gtk.css" = {
    source = "${config.programs.matugen.theme.files}/gtk.css";
  };

  programs.git = {
    enable = true;
    userName = "Tim Peters";
    userEmail = "tim@protonomaly.nl";
  };

  home.pointerCursor = {
    name = "Adwaita";
    package = pkgs.gnome.adwaita-icon-theme;
    gtk.enable = true;
    size = 24;
  };

  gtk = {
    enable = true;
    theme = {
      name = "adw-gtk3-dark";
      package = pkgs.adw-gtk3;
    };
    iconTheme = {
      name = "Adwaita";
      package = pkgs.gnome.adwaita-icon-theme;
    };
  };

  dconf.settings = {
    "org/gnome/desktop/interface" = {
      "color-scheme" = "prefer-dark";
    };
  };

  programs.foot = {
    enable = true;
    settings = {
      main = {
        font = "IosevkaTerm Nerd Font:size=10";
      };
    };
  };

  wayland.windowManager.sway = {
    enable = true;
    wrapperFeatures.gtk = true;
    config = {
      modifier = "Mod4";
      menu = "wofi --show=drun";
      fonts = {
        names = [ "Iosevka Nerd Font" ];
        size = 10.0;
      };
      window.titlebar = false;
      output = {
        "*" = {
          #bg = "${pkgs.sway}/share/backgrounds/sway/Sway_Wallpaper_Blue_1920x1080.png fill";
          bg = "${./background.jpg} fill";
        };
      };
      seat."*".hide_cursor = "500";
      bars = [
        {
          position = "top";
          statusCommand = "while date +'%Y-%m-%d %I:%M:%S %p'; do sleep 1; done";
          fonts = {
            names = [ "Iosevka Nerd Font" ];
            size = 10.0;
          };
          colors = {
            statusline = "#ffffff";
            #background = "#323232";
            background = config.programs.matugen.theme.colors.surface;
            inactiveWorkspace = {
              #background = "#32323200";
              #border = "#32323200";
              #text = "#5c5c5c";
              background = "${config.programs.matugen.theme.colors.surface}80";
              border = "${config.programs.matugen.theme.colors.surface}80";
              text = config.programs.matugen.theme.colors.on_surface;
            };
          };
        }
      ];
    };
  };
}
